==> kountdown-0.3.2.tar.gz: kountdown-0.3.2/kountdown/main.cpp <==
/***************************************************************************
                          main.cpp  -  Starts the screensaver or screensaver setup
                             -------------------
    begin                : Sun Feb 10 09:52:20 CET 2002
    copyright            : (C) 2002 by Erik Johansson
    email                : erre@telia.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ****************************************************************************/

#include <klocale.h>

#include "kountdown.h"
#include "setupdlg/setupdlg.h"

// libkscreensaver interface
extern "C"
{
    const char *kss_applicationName = "kountdown.kss";
    const char *kss_description = I18N_NOOP( "KountDown, the screensaver that counts down to selected date" );
    const char *kss_version = VERSION;

    KScreenSaver *kss_create( WId id )
    {
        return new Kountdown( id );
    }

    QDialog *kss_setup()
    {
			return new SetupDlg();
    }
}

==> kountdown-0.4.1.tar.gz: kountdown-0.4.1/kountdown/main.cpp <==
/***************************************************************************
                          main.cpp  -  Starts the screensaver or screensaver setup
                             -------------------
    begin                : Sun Feb 10 09:52:20 CET 2002
    copyright            : (C) 2002 by Erik Johansson
    email                : kountdown@erre.user.lysator.liu.se
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ****************************************************************************/

#include <klocale.h>

#include "kountdown.h"
#include "setupdlg/setupdlg.h"

// libkscreensaver interface
extern "C"
{
	const char *kss_applicationName = "kountdown.kss";
	const char *kss_description = I18N_NOOP( "Kountdown, the screensaver that counts down to selected date." );
	const char *kss_version = VERSION;

	KScreenSaver *kss_create( WId id )
	{
		return new Kountdown( id );
	}

	QDialog *kss_setup()
	{
		return new SetupDlg();
	}
}
